@@ -191,6 +191,7 @@ func configureJsFramework(sourceDir string, config *ScannerConfig) (*SourceInfo,
 			srcInfo.DatabaseDesired = DatabaseKindMySQL
 		} else if checksPass(sourceDir+"/prisma", dirContains("*.prisma", "sqlite")) {
 			srcInfo.DatabaseDesired = DatabaseKindSqlite
+			srcInfo.ObjectStorageDesired = true
 		}
 	}
 
@@ -247,6 +248,8 @@ func configureJsFramework(sourceDir string, config *ScannerConfig) (*SourceInfo,
 		srcInfo.Family = "Nust"
 	} else if devdeps["nuxt"] != nil || deps["nuxt"] != nil {
 		srcInfo.Family = "Nuxt"
+	} else if checksPass(sourceDir, fileExists("shopify.app.toml")) {
+		srcInfo.Family = "Shopify"
 	} else if deps["remix"] != nil || deps["@remix-run/node"] != nil {
 		srcInfo.Family = "Remix"
 	} else if devdeps["@sveltejs/kit"] != nil {
@@ -278,9 +281,10 @@ func JsFrameworkCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchP
 		}
 	}
 
-	// generate Dockerfile if it doesn't already exist
+	// run dockerfile-node if Dockerfile doesn't already exist, or there is a database to be set up
 	_, err = os.Stat("Dockerfile")
-	if errors.Is(err, fs.ErrNotExist) {
+	if errors.Is(err, fs.ErrNotExist) || srcInfo.DatabaseDesired == DatabaseKindSqlite || srcInfo.DatabaseDesired == DatabaseKindPostgres {
+		skip := (err == nil)
 		var args []string
 
 		_, err = os.Stat("node_modules")
@@ -335,7 +339,15 @@ func JsFrameworkCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchP
 			cmd.Stderr = os.Stderr
 
 			if err := cmd.Run(); err != nil {
-				return fmt.Errorf("failed to install @flydotio/dockerfile: %w", err)
+				if exitError, ok := err.(*exec.ExitError); ok && exitError.ExitCode() == 42 {
+					// generator exited with code 42, which means existing
+					// Dockerfile contains errors which will prevent deployment.
+					srcInfo.SkipDeploy = true
+					srcInfo.DeployDocs = "Correct the errors and run 'fly deploy' to deploy your app."
+					fmt.Println()
+				} else {
+					return fmt.Errorf("failed to install @flydotio/dockerfile: %w", err)
+				}
 			}
 		}
 
@@ -376,11 +388,21 @@ func JsFrameworkCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchP
 				return fmt.Errorf("failure finding %s executable in PATH", xcmd)
 			}
 
+			// add --skip flag if Dockerfile already exists
+			if skip {
+				args = append(args, "--skip")
+			}
+
 			// add additional flags from launch command
 			if len(flags) > 0 {
 				args = append(args, flags...)
 			}
 
+			// add litestream if object storage is present and database is sqlite3
+			if plan.ObjectStorage.Provider() != nil && srcInfo.DatabaseDesired == DatabaseKindSqlite {
+				args = append(args, "--litestream")
+			}
+
 			// execute (via npx, bunx, or bun x) the docker module
 			cmd := exec.Command(xcmdpath, args...)
 			cmd.Stdin = nil
@@ -388,7 +410,15 @@ func JsFrameworkCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchP
 			cmd.Stderr = os.Stderr
 
 			if err := cmd.Run(); err != nil {
-				return fmt.Errorf("failed to generate Dockerfile: %w", err)
+				if exitError, ok := err.(*exec.ExitError); ok && exitError.ExitCode() == 42 {
+					// generator exited with code 42, which means existing
+					// Dockerfile contains errors which will prevent deployment.
+					srcInfo.SkipDeploy = true
+					srcInfo.DeployDocs = "Correct the errors and run 'fly deploy' to deploy your app.\n"
+					fmt.Println()
+				} else {
+					return fmt.Errorf("failed to generate Dockerfile: %w", err)
+				}
 			}
 		}
 	}
@@ -412,13 +442,15 @@ func JsFrameworkCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchP
 	srcInfo.Family = family
 
 	// provide some advice
-	srcInfo.DeployDocs += fmt.Sprintf(`
+	if srcInfo.DeployDocs == "" {
+		srcInfo.DeployDocs = fmt.Sprintf(`
 If you need custom packages installed, or have problems with your deployment
 build, you may need to edit the Dockerfile for app-specific changes. If you
 need help, please post on https://community.fly.io.
 
 Now: run 'fly deploy' to deploy your %s app.
 `, srcInfo.Family)
+	}
 
 	return nil
 }
